@@ -15,51 +15,52 @@
 ####
 ####**********************************************************************
 ####**********************************************************************
-#' Internal Reciever Operator Characteristic calculator for randomForest objects
-#' 
-#' @details Given the randomForest or randomForestSRC prediction and the actual 
+#' Reciever Operator Characteristic calculator
+#'  
+#' @details For a randomForestSRC prediction and the actual 
 #' response value, calculate the specificity (1-False Positive Rate) and sensitivity 
 #' (True Positive Rate) of a predictor.
 #' 
 #' This is a helper function for the \code{\link{gg_roc}} functions, and not intended 
 #' for use by the end user.
 #' 
-#' @param rf \code{randomForestSRC::rfsrc} or \code{randomForestSRC::predict} object 
+#' @param object \code{randomForestSRC::rfsrc} or \code{randomForestSRC::predict} object 
 #' containing predicted response
-#' @param dta True response variable
+#' @param yvar True response variable
 #' @param which.outcome If defined, only show ROC for this response. 
 #' @param oob Use OOB estimates, the normal validation method (TRUE)
 #'  
+#' @return A \code{gg_roc} object
+#'   
 #' @aliases calc_roc.rfsrc calc_roc.randomForest calc_roc
 #' 
 #' @seealso \code{\link{calc_auc}} \code{\link{gg_roc}} \code{\link{plot.gg_roc}}
 #' 
 #' @importFrom parallel mclapply
 #' 
+#' @export calc_roc calc_roc.rfsrc
 #' @examples
-#' \dontrun{
-#' ##
 #' ## Taken from the gg_roc example
-#' iris.obj <- rfsrc(Species ~ ., data = iris)
-#' gg_dta <- calc_roc.rfsrc(iris.obj, iris.obj$yvar, which.outcome=1, oob=TRUE)
-#' }
+#' # rfsrc_iris <- rfsrc(Species ~ ., data = iris)
+#' data(rfsrc_iris)
+#' gg_dta <- calc_roc.rfsrc(rfsrc_iris, rfsrc_iris$yvar, which.outcome=1, oob=TRUE)
 #' 
-calc_roc.rfsrc <- function(rf, dta, which.outcome="all", oob=TRUE){
-  if(!is.factor(dta)) dta <- factor(dta)
+calc_roc.rfsrc <- function(object, yvar, which.outcome="all", oob=TRUE){
+  if(!is.factor(yvar)) yvar <- factor(yvar)
   if(which.outcome!="all"){
-    dta.roc <- data.frame(cbind(res=(dta == levels(dta)[which.outcome]), 
-                                prd=rf$predicted[, which.outcome],
-                                oob=rf$predicted.oob[, which.outcome]))
+    dta.roc <- data.frame(cbind(res=(yvar == levels(yvar)[which.outcome]), 
+                                prd=object$predicted[, which.outcome],
+                                oob=object$predicted.oob[, which.outcome]))
     if(oob)
-      pct <- sort(unique(rf$predicted.oob[,which.outcome]))
+      pct <- sort(unique(object$predicted.oob[,which.outcome]))
     else
-      pct <- sort(unique(rf$predicted[,which.outcome]))
+      pct <- sort(unique(object$predicted[,which.outcome]))
   }else{
     stop("Must specify which.outcome for now.")
   }
   pct<- pct[-length(pct)]
   
-  gg_dta <-mclapply(pct, function(crit){
+  gg_dta <- mclapply(pct, function(crit){
     if(oob) 
       tbl <- xtabs(~res+(oob>crit), dta.roc)
     else
@@ -72,14 +73,17 @@ calc_roc.rfsrc <- function(rf, dta, which.outcome="all", oob=TRUE){
   
   gg_dta <- do.call(rbind, gg_dta)
   gg_dta <- rbind(c(0,1), gg_dta, c(1,0))
-  pct<- c("origin",pct,"limit")
-  return(data.frame(gg_dta, row.names=pct))
+  
+  gg_dta <- data.frame(gg_dta, row.names=1:nrow(gg_dta))
+  gg_dta$pct <- c(0,pct,1)
+  invisible(gg_dta)
   
 }
 
 calc_roc<- calc_roc.rfsrc
-calc_roc.randomForest <- function(rf, dta, which.outcome=1){
-  prd <- predict(rf, type="prob")
+
+calc_roc.randomForest <- function(object, dta, which.outcome=1){
+  prd <- predict(object, type="prob")
   dta.roc <- data.frame(cbind(res=(dta == levels(dta)[which.outcome]), 
                               prd=prd[,which.outcome]))
   
@@ -93,20 +97,22 @@ calc_roc.randomForest <- function(rf, dta, which.outcome=1){
     sens<-tbl[1,1]/rowSums(tbl)[1]
     cbind(sens=sens, spec=spec)
   })
-  gg_dta <- do.call(rbind, gg_dta)
+  gg_dta <- data.frame(do.call(rbind, gg_dta))
   
-  return(data.frame(gg_dta, row.names=pct))
+  gg_dta$pct <- c(0,pct,1)
+  
+  invisible(gg_dta)
 }
 
 #'
-#' Internal calculator for the Area Under the ROC Curve
+#' Area Under the ROC Curve calculator
 #' 
 #' @details calc_auc uses the trapezoidal rule to calculate the area under
 #' the ROC curve.
 #' 
-#'  This is a helper function for the \code{\link{gg_roc}} functions, and not intended 
-#' for use by the end user.
-#' @param x output from \code{\link{calc_roc}} (or \code{\link{gg_roc}}) 
+#'  This is a helper function for the \code{\link{gg_roc}} functions.
+#'  
+#' @param x \code{\link{gg_roc}} object
 #' 
 #' @return AUC. 50\% is random guessing, higher is better.
 #' 
@@ -115,13 +121,16 @@ calc_roc.randomForest <- function(rf, dta, which.outcome=1){
 #' @seealso \code{\link{calc_roc}} \code{\link{gg_roc}} \code{\link{plot.gg_roc}}
 #' 
 #' @examples
-#' \dontrun{
 #' ##
 #' ## Taken from the gg_roc example
-#' iris.obj <- rfsrc(Species ~ ., data = iris)
-#' roc <- ggRandomForests:::calc_roc.rfsrc(iris.obj, iris.obj$yvar, which.outcome=2, oob=TRUE)
-#' ggRandomForests:::calc_auc(roc)
-#' }
+#' # rfsrc_iris <- rfsrc(Species ~ ., data = iris)
+#' data(rfsrc_iris)
+#' gg_dta <- gg_roc(rfsrc_iris, which.outcome=1)
+#' 
+#' calc_auc(gg_dta)
+#' 
+#' @export calc_auc
+#' @aliases calc_auc calc_auc.gg_roc
 #' 
 calc_auc <- function(x){
   ## Use the trapeziod rule, basically calc
@@ -137,3 +146,4 @@ calc_auc <- function(x){
   auc <- (3*lead(x$sens) - x$sens)/2 * (x$spec - lead(x$spec))
   sum(auc, na.rm=TRUE)
 }
+calc_auc.gg_roc <- calc_auc
\ No newline at end of file
