@@ -22,8 +22,8 @@
 #' @param x \code{\link{gg_minimal_depth}} object created from a \code{randomForestSRC::rfsrc} object
 #' @param selection should we restrict the plot to only include variables selected by the 
 #' minimal depth criteria (boolean).
-#' @param list_vars add text list of ranked variables. Only used if selection = TRUE (boolean)
 #' @param type select type of y axis labels c("named","rank")
+#' @param lbls a vector of alternative variable names.
 #' @param ... optional arguments passed to \code{\link{gg_minimal_depth}}
 #' 
 #' @return \code{ggplot} object
@@ -53,10 +53,10 @@
 #' data(iris_vs, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing minimaldepth measures
-#' ggrf.obj<- gg_minimal_depth(iris_vs)
+#' gg_dta<- gg_minimal_depth(iris_vs)
 #' 
 #' # Plot the gg_mkinimal_depth object
-#' plot(ggrf.obj)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## Regression example
@@ -67,10 +67,10 @@
 #' data(airq_vs, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing error rates
-#' ggrf.obj<- gg_minimal_depth(airq_vs)
+#' gg_dta<- gg_minimal_depth(airq_vs)
 #' 
 #' # Plot the gg_error object
-#' plot(ggrf.obj)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## Survival example
@@ -83,94 +83,92 @@
 #' # Load a cached randomForestSRC object
 #' data(veteran_vs, package="ggRandomForests")
 #' 
-#' ggrf.obj <- gg_minimal_depth(veteran_vs)
-#' plot(ggrf.obj)
+#' gg_dta <- gg_minimal_depth(veteran_vs)
+#' plot(gg_dta)
 #' 
 #' }
-#' @importFrom ggplot2 ggplot geom_line theme aes_string labs coord_cartesian geom_text annotate geom_hline coord_flip geom_vline
+#' @importFrom ggplot2 ggplot geom_line theme aes_string labs coord_cartesian geom_text annotate geom_hline coord_flip geom_vline scale_x_discrete
 ### error rate plot
 plot.gg_minimal_depth <- function(x, selection=FALSE, 
-                                  list_vars = TRUE, 
                                   type=c("named","rank"),
+                                  lbls,
                                   ...){
-  object <- x
+  gg_dta <- x
   if(!inherits(x, "gg_minimal_depth")){
-    object <- gg_minimal_depth(x, ...)
+    gg_dta <- gg_minimal_depth(x, ...)
   }
   type=match.arg(type)
   
-  xl <-c(0,ceiling(max(object$varselect$depth))+1)
-  sel.th = object$md.obj$threshold
+  xl <-c(0,ceiling(max(gg_dta$varselect$depth))+1)
+  sel.th = gg_dta$md.obj$threshold
   
   if(selection){
-    modelSize<-object$modelsize
+    modelSize<-gg_dta$modelsize
     
     # Labels for the top md vars.
-    md.labs <- object$topvars
+    md.labs <- gg_dta$topvars
     
     ## Number the variables
     for(ind in 1:length(md.labs)){
       md.labs[ind] <- paste(ind, md.labs[ind], sep=". ")
     }
-    vSel <- object$varselect[1:modelSize,]
+    vSel <- gg_dta$varselect[1:modelSize,]
     vSel$rank <- 1:nrow(vSel)
     
     ## Reorder the minimal depth to place most "important" at top of figure
     vSel$names <- factor(vSel$names, 
                          levels=rev(levels(vSel$names )))
-    gDta <- ggplot(vSel)
-    gDta <- switch(type,
-                   rank = gDta +
+    gg_plt <- ggplot(vSel)
+    gg_plt <- switch(type,
+                   rank = gg_plt +
                      geom_point(aes_string(y="rank", x="depth", label="rank"))+
                      coord_cartesian(xlim=xl) + 
                      geom_text(aes_string(y="rank", x="depth"-.7, label="rank"), 
                                size=3, hjust=0),
-                   named = gDta +
+                   named = gg_plt +
                      geom_point(aes_string(y="depth", x="names"))+
                      coord_cartesian(ylim=xl)
     )
     
-    if(list_vars){
-      
-      # We will need to modify this as we get more examples.
-      x.pt <- ceiling(object$md.obj$threshold)
-      
-      # Populate the text box with min.depth ordered labels
-      yPlace= object$modelsize -1
-      
-      for(ind in 1:length(md.labs)){
-        gDta <- gDta +
-          annotate(x=x.pt,y=yPlace,geom="text",label=md.labs[ind], hjust=0,size=3)
-        yPlace <- yPlace - .95
-      }
-    }
     
   }else{ 
-    vSel <- object$varselect
+    vSel <- gg_dta$varselect
     vSel$rank <- 1:dim(vSel)[1]
     vSel$names <- factor(vSel$names, 
                          levels=rev(levels(vSel$names )))
-    gDta <- ggplot(vSel)
-    gDta <- switch(type,
-                   rank = gDta +
+    gg_plt <- ggplot(vSel)
+    gg_plt <- switch(type,
+                   rank = gg_plt +
                      geom_point(aes_string(y="rank", x="depth"))+
                      coord_cartesian(xlim=xl),
-                   named  =gDta +
+                   named  =gg_plt +
                      geom_point(aes_string(y="depth", x="names"))+
                      coord_cartesian(ylim=xl)
     )
     
   }
   
+  
   if(type=="named"){
-    gDta <- gDta+
+    if(!missing(lbls)){
+      if(length(lbls) >= length(vSel$names)){
+        st.lbls <- lbls[as.character(vSel$names)]
+        names(st.lbls) <- as.character(vSel$names)
+        st.lbls[which(is.na(st.lbls))] <- names(st.lbls[which(is.na(st.lbls))])
+        
+        gg_plt <- gg_plt +
+          scale_x_discrete(labels=st.lbls)
+      }
+    }
+    
+    gg_plt <- gg_plt+
       geom_hline(yintercept=sel.th, lty=2)+
       labs(y="Minimal Depth of a Variable", x="")+
       coord_flip() 
   }else{
-    gDta <- gDta+
+    gg_plt <- gg_plt+
       labs(y="Rank", x="Minimal Depth of a Variable")+
       geom_vline(xintercept=sel.th, lty=2)
   }
-  return(gDta)
+  return(gg_plt)
 }
