@@ -3,31 +3,31 @@ context("gg_partial tests")
 
 test_that("gg_partial classifications",{
   ## IF we want to build the forest every time...
-  #   iris_rf <- rfsrc(Species ~ ., data = iris)
-  # iris_rf <- var.select(iris_rf)
+  #   rfsrc_iris <- rfsrc(Species ~ ., data = iris)
+  # varsel_iris <- var.select(rfsrc_iris)
   
   ## Load the cached forest
-  data(iris_rf, package="ggRandomForests")
+  data(rfsrc_iris, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(iris_rf, "rfsrc")
+  expect_is(rfsrc_iris, "rfsrc")
   
   # Test the forest family
-  expect_that(iris_rf$family, equals("class"))
+  expect_that(rfsrc_iris$family, equals("class"))
   
   # Load saved partial plot data.
-  data(iris_prtl, package="ggRandomForests")
+  data(partial_iris, package="ggRandomForests")
   
-  expect_equivalent(length(iris_prtl$pData), length(iris_rf$xvar.names))
+  expect_equivalent(length(partial_iris$pData), length(rfsrc_iris$xvar.names))
   
   ## Create the correct gg_error object
-  gg_dta<- gg_partial(iris_prtl)
+  gg_dta<- gg_partial(partial_iris)
   
   # Test object type
   expect_is(gg_dta, "gg_partial_list")
   
   # Test varselect is the same
- #expect_equivalent(select(gg_dta$varselect, -names), iris_rf$importance)
+ #expect_equivalent(select(gg_dta$varselect, -names), rfsrc_iris$importance)
   
   ## Test plotting the gg_error object
   gg_plt <- plot.gg_partial(gg_dta[[2]])
@@ -41,7 +41,7 @@ test_that("gg_partial classifications",{
  # Test return is s ggplot object
  expect_is(gg_plt[[1]], "ggplot")
  
- expect_equivalent(length(gg_plt),length(iris_prtl$pData) )
+ expect_equivalent(length(gg_plt),length(partial_iris$pData) )
 })
 
 
@@ -49,19 +49,19 @@ test_that("gg_partial survival",{
   
   ## IF we want to build the forest every time...
   #   data(veteran, package = "randomForestSRC")
-  #   veteran_rf <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
-  #   veteran_rf <- var.select(veteran_rf)
+  #   rfsrc_veteran <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
+  #   rfsrc_veteran <- var.select(rfsrc_veteran)
   ## Load the cached forest
-  data(veteran_rf, package="ggRandomForests")
+  data(rfsrc_veteran, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(veteran_rf, "rfsrc")
+  expect_is(rfsrc_veteran, "rfsrc")
   
   ## Get the partial data.
-  data(veteran_prtl, package="ggRandomForests")
+  data(partial_veteran, package="ggRandomForests")
   
   ## Create the correct gg_error object
-  gg_dta <- gg_partial(veteran_prtl)
+  gg_dta <- gg_partial(partial_veteran[[1]])
   
   # Test object type
   expect_is(gg_dta, "gg_partial_list")
@@ -80,7 +80,6 @@ test_that("gg_partial survival",{
   
   expect_equivalent(length(gg_plt) , length(gg_dta))
   
-  
   ## Test plotting the gg_error object
   gg_plt <- plot(gg_dta, panel=TRUE)
   
@@ -92,17 +91,17 @@ test_that("gg_partial regression",{
   
   ## IF we want to build the forest every time...
   #   ## New York air quality measurements
-  #   airq.obj <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
-  #   airq_rf <- var.select(airq_rf)
+  #   rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
+  #   rfsrc_airq <- var.select(rfsrc_airq)
   ## Load the cached forest
-  data(airq_rf, package="ggRandomForests")
+  data(rfsrc_airq, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(airq_rf, "rfsrc")
+  expect_is(rfsrc_airq, "rfsrc")
   
   ## Create the correct gg_error object
-  data(airq_prtl, package="ggRandomForests")
-  gg_dta<- gg_partial(airq_prtl)
+  data(partial_airq, package="ggRandomForests")
+  gg_dta<- gg_partial(partial_airq)
   
   # Test object type
   expect_is(gg_dta, "gg_partial_list")
