@@ -3,26 +3,26 @@ context("gg_variable tests")
 
 test_that("gg_variable classifications",{
   ## IF we want to build the forest every time...
-  #   iris_rf <- rfsrc(Species ~ ., data = iris)
-  # iris_rf <- var.select(iris_rf)
+  #   rfsrc_iris <- rfsrc(Species ~ ., data = iris)
+  # rfsrc_iris <- var.select(rfsrc_iris)
   
   ## Load the cached forest
-  data(iris_rf, package="ggRandomForests")
+  data(rfsrc_iris, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(iris_rf, "rfsrc")
+  expect_is(rfsrc_iris, "rfsrc")
   
   # Test the forest family
-  expect_that(iris_rf$family, equals("class"))
+  expect_that(rfsrc_iris$family, equals("class"))
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(iris_rf)
+  ggrf.obj<- gg_variable(rfsrc_iris)
   
   # Test object type
   expect_is(ggrf.obj, "gg_variable")
 #   
 #   ## Test plotting the gg_error object
-#   gg.obj <- plot.gg_variable(ggrf.obj, x_var = "Petal.Width", )
+#   gg.obj <- plot.gg_variable(ggrf.obj, xvar = "Petal.Width", )
 #   
 #   # Test return is s ggplot object
 #   expect_is(gg.obj, "ggplot")
@@ -33,22 +33,22 @@ test_that("gg_variable survival",{
   
   ## IF we want to build the forest every time...
   #   data(veteran, package = "randomForestSRC")
-  #   veteran_rf <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
-  #   veteran_rf <- var.select(veteran_rf)
+  #   rfsrc_veteran <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
+  #   rfsrc_veteran <- var.select(rfsrc_veteran)
   ## Load the cached forest
-  data(veteran_rf, package="ggRandomForests")
+  data(rfsrc_veteran, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(veteran_rf, "rfsrc")
+  expect_is(rfsrc_veteran, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(veteran_rf, time=30)
+  ggrf.obj<- gg_variable(rfsrc_veteran, time=30)
   
   # Test object type
   expect_is(ggrf.obj, "gg_variable")
   
   ## Test plotting the gg_variable object
-  gg.obj <- plot.gg_variable(ggrf.obj, x_var="age")
+  gg.obj <- plot.gg_variable(ggrf.obj, xvar="age")
   
   # Test return is s ggplot object
   expect_is(gg.obj, "ggplot")
@@ -59,15 +59,15 @@ test_that("gg_variable regression",{
   ## IF we want to build the forest every time...
   #   ## New York air quality measurements
   #   airq.obj <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
-  #   airq_rf <- var.select(airq_rf)
+  #   rfsrc_airq <- var.select(rfsrc_airq)
   ## Load the cached forest
-  data(airq_rf, package="ggRandomForests")
+  data(rfsrc_airq, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(airq_rf, "rfsrc")
+  expect_is(rfsrc_airq, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(airq_rf)
+  ggrf.obj<- gg_variable(rfsrc_airq)
   
   # Test object type
   expect_is(ggrf.obj, "gg_variable")
